package com.ltt.compass.weather.base

import android.content.Context
import android.content.res.Resources
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.os.SystemClock
import android.view.inputmethod.InputMethodManager
import androidx.appcompat.app.AppCompatActivity
import androidx.constraintlayout.widget.ConstraintLayout
import com.google.android.material.appbar.AppBarLayout
import com.ltt.compass.R
import com.ltt.compass.weather.util.DisplayUtils

abstract class BaseActivity : AppCompatActivity(), BaseViewInit {
  private val HANDLER = Handler(Looper.getMainLooper())
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(getContentViewId())
//        SystemBarHelper.Builder()
//                .enableImmersedStatusBar(true) // 布局嵌入状态栏，例如图片嵌入状态栏
//                .enableImmersedNavigationBar(false)  // 布局嵌入导航栏，例如图片嵌入导航栏
//                .navigationBarColor(Color.BLACK)
//                .into(this)
        initViews()
        initData()
    }

    protected fun setAppBarHeight(appBar: AppBarLayout) {
        appBar.layoutParams = ConstraintLayout.LayoutParams( ConstraintLayout.LayoutParams.MATCH_PARENT, (resources.getDimension(R.dimen.qpp_bar_layout_height) + DisplayUtils.getStatusBarHeight(this)+DisplayUtils.dp2px(applicationContext,10f)).toInt())
    }

    /**
     * 延迟执行
     */
    protected fun post(r: Runnable): Boolean {
        return postDelayed(r, 0)
    }

    /**
     * 延迟一段时间执行
     */
    protected fun postDelayed(r: Runnable, delayMillis: Long): Boolean {
        var time = delayMillis
        if (time < 0) {
            time = 0
        }
        return postAtTime(r, SystemClock.uptimeMillis() + time)
    }

    /**
     * 在指定的时间执行
     */
    protected fun postAtTime(r: Runnable, uptimeMillis: Long): Boolean {
        return HANDLER.postAtTime(r, this, uptimeMillis)
    }

    override fun onDestroy() {
        super.onDestroy()
        // 移除和这个 Activity 相关的消息回调
        HANDLER.removeCallbacksAndMessages(this)
    }

    /**
     * 隐藏软键盘
     */
    protected open fun hideSoftKeyboard() { // 隐藏软键盘，避免软键盘引发的内存泄露
        val view = currentFocus
        if (view != null) {
            val manager = getSystemService(Context.INPUT_METHOD_SERVICE) as InputMethodManager
            manager.hideSoftInputFromWindow(view.windowToken, 0)
        }
    }

    override fun getResources(): Resources {
        val resources = super.getResources()
        if (resources != null && resources.configuration.fontScale != 1.0f) {
            val configuration = resources.configuration
            configuration.fontScale = 1.0f
            resources.updateConfiguration(configuration, resources.displayMetrics)
        }
        return resources
    }
}

