package com.ltt.compass.weather.contract

import com.ltt.compass.weather.base.BasePresenter
import com.ltt.compass.weather.base.IBaseModel
import com.ltt.compass.weather.base.IBaseView
import com.ltt.compass.weather.bean.*
import com.ltt.compass.weather.util.WeatherUtils

interface WeatherContract {
    interface IWeatherModel : IBaseModel {
        fun getWeather(cityId: String): CurrentWeatherData?
        fun saveWeather(cityId: String, weatherData: CurrentWeatherData)
        fun getHourWeather(cityId: String): HourWeatherData?
        fun saveHourWeather(cityId: String, hourWeatherData: HourWeatherData)
        fun getDailyDayWeather(cityId: String): DailyDayWeatherData?
        fun saveDailyDayWeather(cityId: String, dailyWeatherData: DailyDayWeatherData)
        fun getObservation(cityId: String): ObservationData?
        fun saveObservation(cityId: String, observationData: ObservationData)
    }

    interface IWeatherView : IBaseView { //V层
        fun updateWeather(needRefresh: Boolean)
        /**
         * 获取当天天气
         */
        fun getCurrentWeatherSuccess(currentWeather: CurrentWeatherData.CurrentWeatherDataBean)

        /**
         * 获取24小时天气
         */
        fun getHourWeatherSuccess(hourWeather: List<HourWeatherData.HourWeatherDataBean>)

        /**
         * 获取10日天气
         */
        fun getDailyDayWeatherSuccess(dailyWeather:  DailyDayWeatherData.DailyDayWeatherDataBean)
        /**
         * 获取空气质量
         */
        fun getObservationSuccess(observationData: ObservationData.ObservationDataBean)
        /**
         * 获取指数
         */
        fun getIndicesDailySuccess(indicesDaily: List<WeatherIndices.WeatherIndicesBean>, indicesType : WeatherUtils.WeatherIndicesType )
    }

    abstract class WeatherPresenter : BasePresenter<IWeatherView>() { //P层
        /**
         * 获取当天天气
         */
        abstract fun getCurrentWeather(cityId: String,needRefresh:Boolean)

        /**
         * 获取24小时天气
         */
        abstract fun getHourWeather(cityId: String,needRefresh:Boolean)
        /**
         * 获取10日天气  isMetric是否是公制
         */
        abstract fun getDailyDayWeather(cityId: String,needRefresh:Boolean)
        /**
         * 获取空气质量
         */
        abstract fun getObservations(cityId: String,needRefresh:Boolean)
        /**
         * 获取指数
         */
        abstract fun getIndicesDaily(cityId: String, indicesType :WeatherUtils.WeatherIndicesType)
    }
}