package com.ltt.compass.weather.presenter

import android.util.Log
import com.dotools.umlibrary.UMPostUtils
import com.ltt.compass.weather.AppConfig
import com.ltt.compass.weather.api.ApiConstants
import com.ltt.compass.weather.api.ResultCallBack
import com.ltt.compass.weather.api.RetrofitRequest
import com.ltt.compass.weather.bean.*
import com.ltt.compass.weather.contract.WeatherContract
import com.ltt.compass.weather.model.WeatherModelImp
import com.ltt.compass.weather.util.HttpPostRequestUtil
import com.ltt.compass.weather.util.SettingConfig
import com.ltt.compass.weather.util.TimeUtil
import com.ltt.compass.weather.util.WeatherUtils
import java.util.*

class WeatherPresenterImp : WeatherContract.WeatherPresenter() {
    private val mModel: WeatherModelImp = WeatherModelImp()

    override fun initDb() {
        mModel.initDb(mViewRef!!.get()!!.getContext())
        RetrofitRequest.getInstance().setApiBaseUrl(ApiConstants.BASE_URL)
    }


    override fun getCurrentWeather(cityId: String, needRefresh: Boolean) {
        if (!needRefresh) {
            val weather = mModel.getWeather(cityId)
            if (weather != null) {
                mViewRef!!.get()!!.getCurrentWeatherSuccess(weather.data!![0])
                if (!TimeUtil.needRefresh(weather.timeStamp)) {
                    return
                }
            }
        }
        Log.e(AppConfig.WEATHER_TAG, "刷新当前")
        RetrofitRequest.getInstance().sendPostMapRequest(ApiConstants.SEARCH_CURRENT_WEATHER_URL, HttpPostRequestUtil.getCurrentWeather(cityId), object : ResultCallBack<CurrentWeatherData> {
            override fun onReadyResult() {

            }

            override fun onSuccess(t: CurrentWeatherData) {
                if (t.statusCode == 200) {
                    mModel.saveWeather(cityId, t)
                    mViewRef!!.get()!!.getCurrentWeatherSuccess(t.data!![0])
                } else {
                    postErrorUm(t.statusCode, "city:$cityId-WeatherPresenter-CurrentWeather:" + t.errorMsg!!)
                    mViewRef!!.get()!!.showError("服务器繁忙")
                }
            }

            override fun onSuccessJson(json: String) {
            }

            override fun onFailure(code: Int, msg: String) {
                postErrorUm(code, msg)
                mViewRef?.get()?.showError("服务器繁忙")
            }
        })
    }

    override fun getHourWeather(cityId: String, needRefresh: Boolean) {
        if (!needRefresh) {
            val hourWeather = mModel.getHourWeather(cityId)
            if (hourWeather != null) {
                mViewRef!!.get()!!.getHourWeatherSuccess(hourWeather.data!!)
                if (!TimeUtil.needRefresh(hourWeather.timeStamp)) {
                    return
                }
            }
        }
        Log.e(AppConfig.WEATHER_TAG, "刷新小时")
        RetrofitRequest.getInstance().sendPostMapRequest(ApiConstants.SEARCH_24HOUR_WEATHER_URL, HttpPostRequestUtil.get24HourWeather(cityId, SettingConfig.getInstance(mViewRef!!.get()!!.getContext()).getTemperatureIsMetric()), object : ResultCallBack<HourWeatherData> {
            override fun onReadyResult() {

            }

            override fun onSuccess(t: HourWeatherData) {
                if (t.statusCode == 200) {
                    mModel.saveHourWeather(cityId, t)
                    mViewRef!!.get()!!.getHourWeatherSuccess(t.data!!)
                } else {
                    postErrorUm(t.statusCode, "city:$cityId-WeatherPresenter-Hour:" + t.errorMsg!!)
                }
            }

            override fun onSuccessJson(json: String) {
            }

            override fun onFailure(code: Int, msg: String) {
                postErrorUm(code, "city:$cityId-WeatherPresenter-Hour:$msg")
            }
        })
    }

    override fun getDailyDayWeather(cityId: String, needRefresh: Boolean) {
        if (!needRefresh) {
            val dailyWeather = mModel.getDailyDayWeather(cityId)
            if (dailyWeather != null) {
                mViewRef!!.get()!!.getDailyDayWeatherSuccess(dailyWeather.data!!)
                if (!TimeUtil.needRefresh(dailyWeather.timeStamp)) {
                    return
                }
            }
        }
        Log.e(AppConfig.WEATHER_TAG, "刷新10日")
        RetrofitRequest.getInstance().sendPostMapRequest(ApiConstants.SEARCH_10DAY_WEATHER_URL, HttpPostRequestUtil.get10DayWeather(cityId, SettingConfig.getInstance(mViewRef!!.get()!!.getContext()).getTemperatureIsMetric()), object : ResultCallBack<DailyDayWeatherData> {
            override fun onReadyResult() {

            }

            override fun onSuccess(t: DailyDayWeatherData) {
                if (t.statusCode == 200) {
                    mModel.saveDailyDayWeather(cityId, t)
                    mViewRef!!.get()!!.getDailyDayWeatherSuccess(t.data!!)
                } else {
                    postErrorUm(t.statusCode, "city:$cityId-WeatherPresenter-DailyDay:" + t.errorMsg!!)
                }
            }

            override fun onSuccessJson(json: String) {

            }

            override fun onFailure(code: Int, msg: String) {
                postErrorUm(code, "city:$cityId-WeatherPresenter-DailyDay:$msg")
            }
        })
    }

    override fun getObservations(cityId: String, needRefresh: Boolean) {
        if (!needRefresh) {
            val observation = mModel.getObservation(cityId)
            if (observation != null) {
                mViewRef!!.get()!!.getObservationSuccess(observation.data!!)
                if (!TimeUtil.needRefresh(observation.timeStamp)) {
                    return
                }
            }
        }
        Log.e(AppConfig.WEATHER_TAG, "刷新空气")
        RetrofitRequest.getInstance().sendPostMapRequest(ApiConstants.SEARCH_OBSERVATIONS_URL, HttpPostRequestUtil.observations(cityId), object : ResultCallBack<ObservationData> {
            override fun onReadyResult() {

            }

            override fun onSuccess(t: ObservationData) {
                if (t.statusCode == 200) {
                    mModel.saveObservation(cityId, t)
                    mViewRef!!.get()!!.getObservationSuccess(t.data!!)
                } else {
                    postErrorUm(t.statusCode, "city:$cityId-WeatherPresenter-Observations:" + t.errorMsg!!)
                }
            }

            override fun onSuccessJson(json: String) {
            }

            override fun onFailure(code: Int, msg: String) {
                postErrorUm(code, "city:$cityId-WeatherPresenter-Observations:$msg")
            }
        })
    }

    override fun getIndicesDaily(cityId: String, indicesType: WeatherUtils.WeatherIndicesType) {

        Log.e(AppConfig.WEATHER_TAG, "刷新指数")
        RetrofitRequest.getInstance().sendPostMapRequest(ApiConstants.SEARCH_INDICES_DAILY_URL, HttpPostRequestUtil.indicesDaily(cityId, indicesType), object : ResultCallBack<WeatherIndices> {
            override fun onReadyResult() {

            }

            override fun onSuccess(t: WeatherIndices) {
                if (t.statusCode == 200) {
                    mViewRef!!.get()!!.getIndicesDailySuccess(t.data!!, indicesType)
                } else {
                    postErrorUm(t.statusCode, "city:$cityId-WeatherPresenter-IndicesDaily:" + t.errorMsg!!)
                }
            }

            override fun onSuccessJson(json: String) {
            }

            override fun onFailure(code: Int, msg: String) {
                postErrorUm(code, "city:$cityId-WeatherPresenter-IndicesDaily:$msg")
            }
        })
    }






    private fun postErrorUm(errorCode: Int, msg: String) {
        if (mViewRef?.get() != null) {
            Log.e(AppConfig.WEATHER_TAG, msg)
            val map = HashMap<String, String>()
            map["error"] = "code:$errorCode-$msg"
            UMPostUtils.onEventMap(mViewRef?.get()!!.getContext(), AppConfig.SERVICE_BUSY_NO_DATA, map)
        }
    }

}