package com.ltt.compass.weather.util

import android.content.ContentValues
import android.content.Context
import android.database.Cursor
import android.database.sqlite.SQLiteDatabase
import android.database.sqlite.SQLiteOpenHelper

class DataBaseOpenHelper private constructor(context: Context, private val nowDbName: String, dbVersion: Int) : SQLiteOpenHelper(context, nowDbName, null, dbVersion) {
    interface OnSqlLiteUpdateListener {
        fun onSqlLiteUpdateListener(db: SQLiteDatabase?, oldVersion: Int, newVersion: Int)
    }

    private var sqlLiteUpdateListener: OnSqlLiteUpdateListener? = null

    override fun onCreate(db: SQLiteDatabase) {
        /**
         * 建表语句列表
         */
        db.execSQL("CREATE TABLE " + DB_TABLE_NAME +
                " (" + CITY_ID +
                " varchar primary key," + CITY_JSON +
                " varchar," + CURRENT_WEATHER_JSON +
                " varchar," + DAILY_WEATHER_JSON +
                " varchar," + HOUR_WEATHER_JSON +
                " varchar," + OBSERVATIONS_JSON + " varchar," + CITY_ORDER + " Int)")
    }

    /**
     * @param @param sql
     * @param @param bindArgs
     * @return void
     * @Title: execSQL
     * @Description: Sql写入
     */
    fun execSQL(sql: String?, bindArgs: Array<Any?>?) {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.writableDatabase
            database.execSQL(sql, bindArgs)
        }
    }

    /**
     * @param @param sql
     * @param @param bindArgs
     * @return void
     * @sql: execSQL
     */
    fun execSQL(sql: String?) {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.writableDatabase
            database.execSQL(sql)
        }
    }

    /**
     * @param @param  sql查询
     * @param @param  bindArgs
     * @param @return
     * @return Cursor
     * @Title: rawQuery
     * @Description:
     */
    fun rawQuery(sql: String?, bindArgs: Array<String?>?): Cursor {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.readableDatabase
            return database.rawQuery(sql, bindArgs)
        }
    }

    /**
     * @param @param table
     * @param @param contentValues 设定文件
     * @return void 返回类型
     * @throws
     * @Title: insert
     * @Description: 插入数据
     */
    fun insert(table: String?, contentValues: ContentValues?): Long {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.writableDatabase
            return database.insert(table, null, contentValues)
        }
    }

    /**
     * @param @param table
     * @param @param values
     * @param @param whereClause
     * @param @param whereArgs 设定文件
     * @return void 返回类型
     * @throws
     * @Title: update
     * @Description: 更新
     */
    fun update(table: String?, values: ContentValues?, whereClause: String?, whereArgs: Array<String?>?) {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.writableDatabase
            database.update(table, values, whereClause, whereArgs)
        }
    }

    /**
     * @param @param table
     * @param @param whereClause
     * @param @param whereArgs
     * @return void
     * @Title: delete
     * @Description:删除
     */
    fun delete(table: String, whereClause: String, whereArgs: Array<String>): Int {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.writableDatabase
            return database.delete(table, whereClause, whereArgs)
        }
    }

    /**
     * @param @param table
     * @param @param columns
     * @param @param selection
     * @param @param selectionArgs
     * @param @param groupBy
     * @param @param having
     * @param @param orderBy
     * @return void
     * @Title: query
     * @Description: 查
     */
    fun query(table: String?, columns: Array<String?>?, selection: String?, selectionArgs: Array<String?>?, groupBy: String?, having: String?,
              orderBy: String?): Cursor {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.readableDatabase
            // Cursor cursor = database.rawQuery("select * from "
// + TableName.TABLE_NAME_USER + " where userId =" + userId, null);
            return database.query(table, columns, selection, selectionArgs, groupBy, having, orderBy)
        }
    }

    /**
     * @param table
     * @param columns
     * @param selection
     * @param selectionArgs
     * @param groupBy
     * @param having
     * @param orderBy
     * @param limit
     * @return
     * @Description:查
     */
    fun query(table: String?, columns: Array<String?>?, selection: String?, selectionArgs: Array<String?>?, groupBy: String?, having: String?,
              orderBy: String?, limit: String?): Cursor {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.readableDatabase
            return database.query(table, columns, selection, selectionArgs, groupBy, having, orderBy, limit)
        }
    }

    /**
     * @param @return
     * @return Cursor
     * @Description 查询，方法重载,table表名，sqlString条件
     */
    fun query(tableName: String, sqlString: String): Cursor {
        val dataBaseOpenHelper = dbMaps[nowDbName]
        synchronized(dataBaseOpenHelper!!) {
            val database = dataBaseOpenHelper.readableDatabase
            return database.rawQuery("select * from $tableName $sqlString", null)
        }
    }


    /**
     * onUpgrade()方法在数据库版本每次发生变化时都会把用户手机上的数据库表删除，然后再重新创建。<br></br>
     * 一般在实际项目中是不能这样做的，正确的做法是在更新数据库表结构时，还要考虑用户存放于数据库中的数据不会丢失,从版本几更新到版本几。(非
     * Javadoc)
     */
    override fun onUpgrade(db: SQLiteDatabase, arg1: Int, arg2: Int) {
        if (sqlLiteUpdateListener != null) {
            sqlLiteUpdateListener!!.onSqlLiteUpdateListener(db, arg1, arg2)
        }
    }

    fun setOnSqlLiteUpdateListener(sqlLiteUpdateListener: OnSqlLiteUpdateListener?) {
        this.sqlLiteUpdateListener = sqlLiteUpdateListener
    }

    companion object {
        private val dbMaps: MutableMap<String, DataBaseOpenHelper> = HashMap()
        const val DB_NAME = "weather_cache.db"
        const val DB_TABLE_NAME = "weather_cache"
        const val DB_VERSION = 2
        const val CITY_ID = "cityId"
        const val CITY_JSON = "cityJson"
        const val CURRENT_WEATHER_JSON = "currentWeatherJson"
        const val DAILY_WEATHER_JSON = "dailyWeatherJson"
        const val HOUR_WEATHER_JSON = "hourWeatherJson"
        const val OBSERVATIONS_JSON = "observationsJson"
        const val CITY_ORDER = "cityOrder"


        /**
         * @param @param  context
         * @param @param  userId
         * @param @return
         * @return DataBaseOpenHelper
         * @Title: getInstance
         * @Description: 获取数据库实例
         */
        fun getInstance(context: Context, dbName: String, dbVersion: Int): DataBaseOpenHelper {
            var dataBaseOpenHelper = dbMaps[dbName]
            if (dataBaseOpenHelper == null) {
                dataBaseOpenHelper = DataBaseOpenHelper(context, dbName, dbVersion)
            }
            dbMaps[dbName] = dataBaseOpenHelper
            return dataBaseOpenHelper
        }
    }

}