package com.ltt.compass.weather.widget


import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.widget.LinearLayout
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.dotools.umlibrary.UMPostUtils
import com.ltt.compass.R
import com.ltt.compass.weather.AppConfig
import com.ltt.compass.weather.bean.MetricAndImperialBean
import com.ltt.compass.weather.bean.ObservationData
import com.ltt.compass.weather.bean.UnitBean
import com.ltt.compass.weather.util.DialogUtil
import com.ltt.compass.weather.util.DisplayUtils
import com.ltt.compass.weather.util.SettingConfig
import com.ltt.compass.weather.util.WeatherUtils

/**
 * 天气头部 对应weather_head.xml
 */
@SuppressLint("StringFormatMatches", "SetTextI18n")
class WeatherHeadView : ConstraintLayout {
    private lateinit var mDegrees: TextView//当前天气度数
    private lateinit var mDegreesUnit: TextView//当前天气度数单位
    private lateinit var mDayDegrees: TextView//当天度数最大最小
    private lateinit var mWeatherText: TextView//当前天气实况的说明
    private lateinit var mObservationNum: TextView//空气质量数值
    private lateinit var mObservationText: TextView//空气质量优良
    private lateinit var mObservationLayout: LinearLayout//空气质量布局可点击
    private lateinit var mObservationWeatherData: ObservationData.ObservationDataBean//空气质量数据


    constructor (context: Context?) : super(context) {}

    constructor (context: Context?, attrs: AttributeSet?) : super(context, attrs) {}

    constructor (context: Context?, attrs: AttributeSet?, defStyleAttr: Int) : super(context, attrs, defStyleAttr) {}

    fun initViews() {
        mDegrees = findViewById(R.id.degrees)
        mDegreesUnit = findViewById(R.id.degrees_unit)
        mDayDegrees = findViewById(R.id.day_degrees)
        mWeatherText = findViewById(R.id.weather_text)
        mObservationNum = findViewById(R.id.observation_num)
        mObservationText = findViewById(R.id.observation_text)
        mObservationLayout = findViewById(R.id.observation_layout)
//        layoutParams = LinearLayout.LayoutParams(
//                DisplayUtils.getScreenW(context),
//                DisplayUtils.getScreenH(context)- DisplayUtils.dp2px(context,240f))
    }

    /**
     * 设置当前温度
     */
    fun setCurrentDegrees(temperature: MetricAndImperialBean) {
        if (SettingConfig.getInstance(context).getTemperatureIsMetric()) {
            mDegrees.text = temperature.Metric!!.Value.toInt().toString()
            mDegreesUnit.text = resources.getString(R.string.weather_current_degrees_unit, temperature.Metric!!.Unit)
        } else {
            mDegrees.text = temperature.Imperial!!.Value.toInt().toString()
            mDegreesUnit.text = resources.getString(R.string.weather_current_degrees_unit, temperature.Imperial!!.Unit)
        }
    }


    /**
     * 设置当前天气描述
     */
    fun setWeatherText(degrees: String) {
        mWeatherText.text = degrees
    }

    /**
     * 设置当天温度
     */
    fun setToDayDegrees(maxiNum: UnitBean, miniNum: UnitBean) {
        mDayDegrees.text = resources.getString(R.string.weather_degrees, maxiNum.Value.toInt().toString(),  miniNum.Value.toInt().toString())
    }

    /**
     * 设置空气质量相关
     */
    fun setObservationData(data: ObservationData.ObservationDataBean) {
        this.mObservationWeatherData = data
        mObservationLayout.visibility = View.VISIBLE
        mObservationLayout.setOnClickListener {
            UMPostUtils.onEvent(context.applicationContext, AppConfig.AQI_CLICK)
            DialogUtil.showObservationDialog(context, data)
        }
        mObservationText.text = WeatherUtils.getWeatherObservationText(context,mObservationWeatherData.Index)
        mObservationText.setBackgroundResource(WeatherUtils.getWeatherObservationBackground(mObservationWeatherData.Index))
        mObservationNum.text = resources.getString(R.string.observation_num, data.Index)
    }

}