package com.ltt.compass.weather.widget.daily


import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.ltt.compass.R
import com.ltt.compass.weather.widget.daily.TemperatureView

class WeatherItemView : LinearLayout {
    private lateinit var mRootView: View
    private lateinit var mWeek: TextView
    private lateinit var mDate: TextView
    private lateinit var mTemperature: TemperatureView
    private lateinit var mWind: TextView
    private lateinit var mWindLevel: TextView
    private lateinit var mAirLevel: TextView
    private lateinit var mDayIcon: ImageView
    private lateinit var mNightIcon: ImageView

    constructor(context: Context) : super(context) {
        initView(context)
    }

    constructor(context: Context, attrs: AttributeSet? = null) : super(context, attrs) {
        initView(context)
    }




    private fun initView(context: Context) {
        mRootView = LayoutInflater.from(context).inflate(R.layout.weather_daily_item, null)
        mWeek = mRootView.findViewById(R.id.daily_item_week)
        mDate = mRootView.findViewById(R.id.daily_item_date)
        mTemperature = mRootView.findViewById(R.id.daily_item_temperature)
        mWind = mRootView.findViewById(R.id.daily_item_wind)
        mWindLevel = mRootView.findViewById(R.id.daily_item_wind_level)
        mDayIcon = mRootView.findViewById(R.id.daily_item_day_icon)
        mNightIcon = mRootView.findViewById(R.id.daily_item_night_icon)
        mAirLevel = mRootView.findViewById(R.id.daily_item_air_level)
        mRootView.layoutParams = LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT)
        addView(mRootView)
    }

    fun setWeek(week: String) {
        mWeek.text = week
    }

    fun setDate(date: String) {
        mDate.text = date
    }


    fun setWind(wind: String) {
        mWind.text = wind
    }

    fun setWindLevel(windLevel: String) {
        mWindLevel.text = context.getString(R.string.weather_wind_level,windLevel)
    }


    fun getTempX(): Int {
        return mTemperature.x.toInt()
    }

    fun getTempY(): Int {
        return mTemperature.y.toInt()
    }

    fun setAirLevel(airLevel: Int) {
        when (airLevel) {
            1 -> {
                mAirLevel.text = resources.getString(R.string.observation_good)
                mAirLevel.setBackgroundResource(R.drawable.radius_green_bg)
            }
            2 -> {
                mAirLevel.text = resources.getString(R.string.observation_fine)
                mAirLevel.setBackgroundResource(R.drawable.radius_yellow_bg)
            }
            3 -> {
                mAirLevel.text = resources.getString(R.string.observation_mild)
                mAirLevel.setBackgroundResource(R.drawable.radius_orange_bg)
            }
            4 -> {
                mAirLevel.text = resources.getString(R.string.observation_medium)
                mAirLevel.setBackgroundResource(R.drawable.radius_red_bg)
            }
            5 -> {
                mAirLevel.text = resources.getString(R.string.observation_seriously)
                mAirLevel.setBackgroundResource(R.drawable.radius_purple_bg)
            }
            6 -> {
                mAirLevel.text = resources.getString(R.string.observation_serious)
                mAirLevel.setBackgroundResource(R.drawable.radius_deep_purple_bg)
            }
        }
    }

    fun setDayTemp(dayTemp: Int) {
        mTemperature.temperatureDay = dayTemp
    }

    fun setNightTemp(nightTemp: Int) {
        mTemperature.temperatureNight = nightTemp
    }

    fun setDayImg(resId: Int) {
        mDayIcon.setImageResource(resId)
    }

    fun setNightImg(resId: Int) {
        mNightIcon.setImageResource(resId)
    }

    fun setMaxTemp(max: Int) {
        mTemperature.setMaxTemp(max)
    }

    fun setMinTemp(min: Int) {
        mTemperature.setMinTemp(min)
    }

    fun setUnit(unit: String) {
        mTemperature.setTempUnit(unit)
    }
}